"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.connectionmanager.v1.clickhouse_pb2
import yandex.cloud.connectionmanager.v1.greenplum_pb2
import yandex.cloud.connectionmanager.v1.kafka_pb2
import yandex.cloud.connectionmanager.v1.mongodb_pb2
import yandex.cloud.connectionmanager.v1.mysql_pb2
import yandex.cloud.connectionmanager.v1.opensearch_pb2
import yandex.cloud.connectionmanager.v1.postgresql_pb2
import yandex.cloud.connectionmanager.v1.redis_pb2
import yandex.cloud.connectionmanager.v1.trino_pb2
import yandex.cloud.connectionmanager.v1.valkey_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DBType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DBTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DBType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DB_TYPE_UNSPECIFIED: _DBType.ValueType  # 0
    POSTGRESQL: _DBType.ValueType  # 1
    MYSQL: _DBType.ValueType  # 2
    CLICKHOUSE: _DBType.ValueType  # 3
    MONGODB: _DBType.ValueType  # 4
    KAFKA: _DBType.ValueType  # 5
    REDIS: _DBType.ValueType  # 6
    OPENSEARCH: _DBType.ValueType  # 7
    TRINO: _DBType.ValueType  # 8
    VALKEY: _DBType.ValueType  # 9
    GREENPLUM: _DBType.ValueType  # 10

class DBType(_DBType, metaclass=_DBTypeEnumTypeWrapper): ...

DB_TYPE_UNSPECIFIED: DBType.ValueType  # 0
POSTGRESQL: DBType.ValueType  # 1
MYSQL: DBType.ValueType  # 2
CLICKHOUSE: DBType.ValueType  # 3
MONGODB: DBType.ValueType  # 4
KAFKA: DBType.ValueType  # 5
REDIS: DBType.ValueType  # 6
OPENSEARCH: DBType.ValueType  # 7
TRINO: DBType.ValueType  # 8
VALKEY: DBType.ValueType  # 9
GREENPLUM: DBType.ValueType  # 10
global___DBType = DBType

@typing.final
class ConnectionParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POSTGRESQL_FIELD_NUMBER: builtins.int
    MYSQL_FIELD_NUMBER: builtins.int
    MONGODB_FIELD_NUMBER: builtins.int
    CLICKHOUSE_FIELD_NUMBER: builtins.int
    KAFKA_FIELD_NUMBER: builtins.int
    REDIS_FIELD_NUMBER: builtins.int
    OPENSEARCH_FIELD_NUMBER: builtins.int
    TRINO_FIELD_NUMBER: builtins.int
    VALKEY_FIELD_NUMBER: builtins.int
    GREENPLUM_FIELD_NUMBER: builtins.int
    @property
    def postgresql(self) -> yandex.cloud.connectionmanager.v1.postgresql_pb2.PostgreSQLConnection: ...
    @property
    def mysql(self) -> yandex.cloud.connectionmanager.v1.mysql_pb2.MySQLConnection: ...
    @property
    def mongodb(self) -> yandex.cloud.connectionmanager.v1.mongodb_pb2.MongoDBConnection: ...
    @property
    def clickhouse(self) -> yandex.cloud.connectionmanager.v1.clickhouse_pb2.ClickHouseConnection: ...
    @property
    def kafka(self) -> yandex.cloud.connectionmanager.v1.kafka_pb2.KafkaConnection: ...
    @property
    def redis(self) -> yandex.cloud.connectionmanager.v1.redis_pb2.RedisConnection: ...
    @property
    def opensearch(self) -> yandex.cloud.connectionmanager.v1.opensearch_pb2.OpenSearchConnection: ...
    @property
    def trino(self) -> yandex.cloud.connectionmanager.v1.trino_pb2.TrinoConnection: ...
    @property
    def valkey(self) -> yandex.cloud.connectionmanager.v1.valkey_pb2.ValkeyConnection: ...
    @property
    def greenplum(self) -> yandex.cloud.connectionmanager.v1.greenplum_pb2.GreenplumConnection: ...
    def __init__(
        self,
        *,
        postgresql: yandex.cloud.connectionmanager.v1.postgresql_pb2.PostgreSQLConnection | None = ...,
        mysql: yandex.cloud.connectionmanager.v1.mysql_pb2.MySQLConnection | None = ...,
        mongodb: yandex.cloud.connectionmanager.v1.mongodb_pb2.MongoDBConnection | None = ...,
        clickhouse: yandex.cloud.connectionmanager.v1.clickhouse_pb2.ClickHouseConnection | None = ...,
        kafka: yandex.cloud.connectionmanager.v1.kafka_pb2.KafkaConnection | None = ...,
        redis: yandex.cloud.connectionmanager.v1.redis_pb2.RedisConnection | None = ...,
        opensearch: yandex.cloud.connectionmanager.v1.opensearch_pb2.OpenSearchConnection | None = ...,
        trino: yandex.cloud.connectionmanager.v1.trino_pb2.TrinoConnection | None = ...,
        valkey: yandex.cloud.connectionmanager.v1.valkey_pb2.ValkeyConnection | None = ...,
        greenplum: yandex.cloud.connectionmanager.v1.greenplum_pb2.GreenplumConnection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["clickhouse", b"clickhouse", "greenplum", b"greenplum", "kafka", b"kafka", "mongodb", b"mongodb", "mysql", b"mysql", "opensearch", b"opensearch", "postgresql", b"postgresql", "redis", b"redis", "trino", b"trino", "type", b"type", "valkey", b"valkey"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clickhouse", b"clickhouse", "greenplum", b"greenplum", "kafka", b"kafka", "mongodb", b"mongodb", "mysql", b"mysql", "opensearch", b"opensearch", "postgresql", b"postgresql", "redis", b"redis", "trino", b"trino", "type", b"type", "valkey", b"valkey"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["postgresql", "mysql", "mongodb", "clickhouse", "kafka", "redis", "opensearch", "trino", "valkey", "greenplum"] | None: ...

global___ConnectionParams = ConnectionParams

@typing.final
class LockboxSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NEWEST_VERSION_FIELD_NUMBER: builtins.int
    id: builtins.str
    version: builtins.str
    newest_version: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        version: builtins.str = ...,
        newest_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "newest_version", b"newest_version", "version", b"version"]) -> None: ...

global___LockboxSecret = LockboxSecret

@typing.final
class Connection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    LOCKBOX_SECRET_FIELD_NUMBER: builtins.int
    IS_MANAGED_FIELD_NUMBER: builtins.int
    CAN_USE_FIELD_NUMBER: builtins.int
    id: builtins.str
    folder_id: builtins.str
    name: builtins.str
    description: builtins.str
    created_by: builtins.str
    is_managed: builtins.bool
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def params(self) -> global___ConnectionParams: ...
    @property
    def lockbox_secret(self) -> global___LockboxSecret: ...
    @property
    def can_use(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_by: builtins.str = ...,
        params: global___ConnectionParams | None = ...,
        lockbox_secret: global___LockboxSecret | None = ...,
        is_managed: builtins.bool = ...,
        can_use: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["can_use", b"can_use", "created_at", b"created_at", "lockbox_secret", b"lockbox_secret", "params", b"params", "secret", b"secret", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["can_use", b"can_use", "created_at", b"created_at", "created_by", b"created_by", "description", b"description", "folder_id", b"folder_id", "id", b"id", "is_managed", b"is_managed", "labels", b"labels", "lockbox_secret", b"lockbox_secret", "name", b"name", "params", b"params", "secret", b"secret", "updated_at", b"updated_at"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["secret", b"secret"]) -> typing.Literal["lockbox_secret"] | None: ...

global___Connection = Connection



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/apigateway/websocket/v1/connection.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/apigateway/websocket/v1/connection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@yandex/cloud/serverless/apigateway/websocket/v1/connection.proto\x12/yandex.cloud.serverless.apigateway.websocket.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdf\x01\n\nConnection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ngateway_id\x18\x02 \x01(\t\x12K\n\x08identity\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.serverless.apigateway.websocket.v1.Identity\x12\x30\n\x0c\x63onnected_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0elast_active_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x08Identity\x12\x11\n\tsource_ip\x18\x01 \x01(\t\x12\x12\n\nuser_agent\x18\x02 \x01(\tB\x94\x01\n3yandex.cloud.api.serverless.apigateway.websocket.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/websocket/v1;websocketb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.apigateway.websocket.v1.connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3yandex.cloud.api.serverless.apigateway.websocket.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/websocket/v1;websocket'
  _globals['_CONNECTION']._serialized_start=151
  _globals['_CONNECTION']._serialized_end=374
  _globals['_IDENTITY']._serialized_start=376
  _globals['_IDENTITY']._serialized_end=425
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/mdbproxy/v1/proxy.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/mdbproxy/v1/proxy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/serverless/mdbproxy/v1/proxy.proto\x12#yandex.cloud.serverless.mdbproxy.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xa8\x03\n\x05Proxy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x04name\x18\x04 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x8b\x01\n\x06labels\x18\x06 \x03(\x0b\x32\x36.yandex.cloud.serverless.mdbproxy.v1.Proxy.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12;\n\x06target\x18\x07 \x01(\x0b\x32+.yandex.cloud.serverless.mdbproxy.v1.Target\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8e\x04\n\x06Target\x12L\n\nclickhouse\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.serverless.mdbproxy.v1.Target.ClickHouseH\x00\x12L\n\npostgresql\x18\x02 \x01(\x0b\x32\x36.yandex.cloud.serverless.mdbproxy.v1.Target.PostgreSQLH\x00\x1a\xac\x01\n\nPostgreSQL\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04user\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x10\n\x08password\x18\x03 \x01(\t\x12*\n\x02\x64\x62\x18\x04 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x10\n\x08\x65ndpoint\x18\x05 \x01(\t\x1a\xab\x01\n\nClickHouse\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x04user\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12\x10\n\x08password\x18\x03 \x01(\t\x12*\n\x02\x64\x62\x18\x04 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x10\n\x08\x65ndpoint\x18\x05 \x01(\tB\x0b\n\x03mdb\x12\x04\xc0\xc1\x31\x01\x42x\n\'yandex.cloud.api.serverless.mdbproxy.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mdbproxy/v1;proxyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.mdbproxy.v1.proxy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'yandex.cloud.api.serverless.mdbproxy.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mdbproxy/v1;proxy'
  _globals['_PROXY_LABELSENTRY']._loaded_options = None
  _globals['_PROXY_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_PROXY'].fields_by_name['folder_id']._loaded_options = None
  _globals['_PROXY'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PROXY'].fields_by_name['name']._loaded_options = None
  _globals['_PROXY'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_PROXY'].fields_by_name['labels']._loaded_options = None
  _globals['_PROXY'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_TARGET_POSTGRESQL'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_TARGET_POSTGRESQL'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_TARGET_POSTGRESQL'].fields_by_name['user']._loaded_options = None
  _globals['_TARGET_POSTGRESQL'].fields_by_name['user']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_TARGET_POSTGRESQL'].fields_by_name['db']._loaded_options = None
  _globals['_TARGET_POSTGRESQL'].fields_by_name['db']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_TARGET_CLICKHOUSE'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_TARGET_CLICKHOUSE'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_TARGET_CLICKHOUSE'].fields_by_name['user']._loaded_options = None
  _globals['_TARGET_CLICKHOUSE'].fields_by_name['user']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _globals['_TARGET_CLICKHOUSE'].fields_by_name['db']._loaded_options = None
  _globals['_TARGET_CLICKHOUSE'].fields_by_name['db']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_TARGET'].oneofs_by_name['mdb']._loaded_options = None
  _globals['_TARGET'].oneofs_by_name['mdb']._serialized_options = b'\300\3011\001'
  _globals['_PROXY']._serialized_start=153
  _globals['_PROXY']._serialized_end=577
  _globals['_PROXY_LABELSENTRY']._serialized_start=532
  _globals['_PROXY_LABELSENTRY']._serialized_end=577
  _globals['_TARGET']._serialized_start=580
  _globals['_TARGET']._serialized_end=1106
  _globals['_TARGET_POSTGRESQL']._serialized_start=747
  _globals['_TARGET_POSTGRESQL']._serialized_end=919
  _globals['_TARGET_CLICKHOUSE']._serialized_start=922
  _globals['_TARGET_CLICKHOUSE']._serialized_end=1093
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.cdn.v1.origin_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OriginGroup(google.protobuf.message.Message):
    """Origin group parameters. For details about the concept, see [documentation](/docs/cdn/concepts/origins#groups)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    USE_NEXT_FIELD_NUMBER: builtins.int
    ORIGINS_FIELD_NUMBER: builtins.int
    PROVIDER_TYPE_FIELD_NUMBER: builtins.int
    RESOURCES_METADATA_FIELD_NUMBER: builtins.int
    id: builtins.int
    """ID of the origin group. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the origin group belongs to."""
    name: builtins.str
    """Name of the origin group."""
    use_next: builtins.bool
    """This option have two possible conditions:
    true - the option is active. In case the origin responds with 4XX or 5XX codes,
           use the next origin from the list.
    false - the option is disabled.
    """
    provider_type: builtins.str
    """Type of the CDN provider for this origin group."""
    @property
    def origins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cdn.v1.origin_pb2.Origin]:
        """List of origins."""

    @property
    def resources_metadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceMetadata]:
        """List of CDN resources currently using this origin group."""

    def __init__(
        self,
        *,
        id: builtins.int = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        use_next: builtins.bool = ...,
        origins: collections.abc.Iterable[yandex.cloud.cdn.v1.origin_pb2.Origin] | None = ...,
        provider_type: builtins.str = ...,
        resources_metadata: collections.abc.Iterable[global___ResourceMetadata] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "id", b"id", "name", b"name", "origins", b"origins", "provider_type", b"provider_type", "resources_metadata", b"resources_metadata", "use_next", b"use_next"]) -> None: ...

global___OriginGroup = OriginGroup

@typing.final
class ResourceMetadata(google.protobuf.message.Message):
    """Metadata of a CDN resource referencing an origin group."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CNAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the CDN resource using the origin group."""
    cname: builtins.str
    """CNAME of the CDN resource using the origin group."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cname: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cname", b"cname", "id", b"id"]) -> None: ...

global___ResourceMetadata = ResourceMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.iam.v1.oauth_client_secret_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetOAuthClientSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENT_SECRET_ID_FIELD_NUMBER: builtins.int
    oauth_client_secret_id: builtins.str
    """ID of the OAuthClientSecret resource to return.
    To get the OAuthClientSecret ID, use a [OAuthClientSecretService.List] request.
    """
    def __init__(
        self,
        *,
        oauth_client_secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["oauth_client_secret_id", b"oauth_client_secret_id"]) -> None: ...

global___GetOAuthClientSecretRequest = GetOAuthClientSecretRequest

@typing.final
class ListOAuthClientSecretsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    OAUTH_CLIENT_ID_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListOAuthClientSecretsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListOAuthClientSecretsResponse.next_page_token] returned by a previous list request.
    """
    oauth_client_id: builtins.str
    """ID of the OAuthClient resource to list OAuthClientSecret resources for.
    To get the oauth client ID, use a [yandex.cloud.iam.v1.OAuthClientService.List] request.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        oauth_client_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["oauth_client_id", b"oauth_client_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListOAuthClientSecretsRequest = ListOAuthClientSecretsRequest

@typing.final
class ListOAuthClientSecretsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENT_SECRETS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListOAuthClientSecretsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListOAuthClientSecretsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def oauth_client_secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iam.v1.oauth_client_secret_pb2.OAuthClientSecret]:
        """List of OAuthClientSecret resources of the specified OAuthClient resource"""

    def __init__(
        self,
        *,
        oauth_client_secrets: collections.abc.Iterable[yandex.cloud.iam.v1.oauth_client_secret_pb2.OAuthClientSecret] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "oauth_client_secrets", b"oauth_client_secrets"]) -> None: ...

global___ListOAuthClientSecretsResponse = ListOAuthClientSecretsResponse

@typing.final
class CreateOAuthClientSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    oauth_client_id: builtins.str
    """ID of the OAuthClient resource to create OAuthClientSecret resource for.  
    To get the oauth client ID, use a [yandex.cloud.iam.v1.OAuthClientService.List] request.
    """
    description: builtins.str
    """Description of the OAuthClientResource."""
    def __init__(
        self,
        *,
        oauth_client_id: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "oauth_client_id", b"oauth_client_id"]) -> None: ...

global___CreateOAuthClientSecretRequest = CreateOAuthClientSecretRequest

@typing.final
class CreateOAuthClientSecretMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENT_SECRET_ID_FIELD_NUMBER: builtins.int
    oauth_client_secret_id: builtins.str
    """ID of the OAuthClientSecretResource that is being created."""
    def __init__(
        self,
        *,
        oauth_client_secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["oauth_client_secret_id", b"oauth_client_secret_id"]) -> None: ...

global___CreateOAuthClientSecretMetadata = CreateOAuthClientSecretMetadata

@typing.final
class CreateOAuthClientSecretResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENT_SECRET_FIELD_NUMBER: builtins.int
    SECRET_VALUE_FIELD_NUMBER: builtins.int
    secret_value: builtins.str
    """The secret value of OAuthClientSecret resource.
    This value can be used for lient secret based authentication.
    This value must be stored securely.
    """
    @property
    def oauth_client_secret(self) -> yandex.cloud.iam.v1.oauth_client_secret_pb2.OAuthClientSecret:
        """OAuthClientSecret resource."""

    def __init__(
        self,
        *,
        oauth_client_secret: yandex.cloud.iam.v1.oauth_client_secret_pb2.OAuthClientSecret | None = ...,
        secret_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["oauth_client_secret", b"oauth_client_secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["oauth_client_secret", b"oauth_client_secret", "secret_value", b"secret_value"]) -> None: ...

global___CreateOAuthClientSecretResponse = CreateOAuthClientSecretResponse

@typing.final
class DeleteOAuthClientSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENT_SECRET_ID_FIELD_NUMBER: builtins.int
    oauth_client_secret_id: builtins.str
    """ID of the OAuthClientSecret resource to delete."""
    def __init__(
        self,
        *,
        oauth_client_secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["oauth_client_secret_id", b"oauth_client_secret_id"]) -> None: ...

global___DeleteOAuthClientSecretRequest = DeleteOAuthClientSecretRequest

@typing.final
class DeleteOAuthClientSecretMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OAUTH_CLIENT_SECRET_ID_FIELD_NUMBER: builtins.int
    oauth_client_secret_id: builtins.str
    """ID of the OAuthClientSecretResource that is being deleted."""
    def __init__(
        self,
        *,
        oauth_client_secret_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["oauth_client_secret_id", b"oauth_client_secret_id"]) -> None: ...

global___DeleteOAuthClientSecretMetadata = DeleteOAuthClientSecretMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/role_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/role_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.iam.v1 import role_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_role__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/iam/v1/role_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1eyandex/cloud/iam/v1/role.proto\"/\n\x0eGetRoleRequest\x12\x1d\n\x07role_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"m\n\x10ListRolesRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"V\n\x11ListRolesResponse\x12(\n\x05roles\x18\x01 \x03(\x0b\x32\x19.yandex.cloud.iam.v1.Role\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe3\x01\n\x0bRoleService\x12\x66\n\x03Get\x12#.yandex.cloud.iam.v1.GetRoleRequest\x1a\x19.yandex.cloud.iam.v1.Role\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/iam/v1/roles/{role_id}\x12l\n\x04List\x12%.yandex.cloud.iam.v1.ListRolesRequest\x1a&.yandex.cloud.iam.v1.ListRolesResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/iam/v1/rolesBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.role_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_GETROLEREQUEST'].fields_by_name['role_id']._loaded_options = None
  _globals['_GETROLEREQUEST'].fields_by_name['role_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTROLESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTROLESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTROLESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTROLESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTROLESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTROLESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_ROLESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_ROLESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\031\022\027/iam/v1/roles/{role_id}'
  _globals['_ROLESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_ROLESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\017\022\r/iam/v1/roles'
  _globals['_GETROLEREQUEST']._serialized_start=156
  _globals['_GETROLEREQUEST']._serialized_end=203
  _globals['_LISTROLESREQUEST']._serialized_start=205
  _globals['_LISTROLESREQUEST']._serialized_end=314
  _globals['_LISTROLESRESPONSE']._serialized_start=316
  _globals['_LISTROLESRESPONSE']._serialized_end=402
  _globals['_ROLESERVICE']._serialized_start=405
  _globals['_ROLESERVICE']._serialized_end=632
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/image.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/image.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/baremetal/v1alpha/image.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb1\x03\n\x05Image\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x10\n\x08\x63hecksum\x18\x06 \x01(\t\x12<\n\x06status\x18\x07 \x01(\x0e\x32,.yandex.cloud.baremetal.v1alpha.Image.Status\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x42\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x31.yandex.cloud.baremetal.v1alpha.Image.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\x12\x0c\n\x08UPDATING\x10\x05J\x04\x08\x03\x10\x04J\x04\x08\x08\x10\x64J\x05\x08\x65\x10\xc8\x01\x42r\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.image_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_IMAGE_LABELSENTRY']._loaded_options = None
  _globals['_IMAGE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_IMAGE']._serialized_start=112
  _globals['_IMAGE']._serialized_end=545
  _globals['_IMAGE_LABELSENTRY']._serialized_start=383
  _globals['_IMAGE_LABELSENTRY']._serialized_end=428
  _globals['_IMAGE_STATUS']._serialized_start=430
  _globals['_IMAGE_STATUS']._serialized_end=526
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.baremetal.v1alpha.server_pb2
import yandex.cloud.baremetal.v1alpha.storage_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetServerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the Server resource to return.

    To get the server ID, use a [ServerService.List] request.
    """
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___GetServerRequest = GetServerRequest

@typing.final
class ListServerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list servers in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is greater than `page_size`,
    the service returns a [ListServerResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value is 20.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListServerResponse.next_page_token] returned by a previous list request.
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    Supported fields: ["id", "name", "createdAt"].
    Both snake_case and camelCase are supported for fields.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=` (equal), `:` (substring).
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    Example: "key1='value' AND key2='value'"
    Supported operators: ["AND"].
    Supported fields: ["id", "name", "zoneId", "hardwarePoolId"].
    Both snake_case and camelCase are supported for fields.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListServerRequest = ListServerRequest

@typing.final
class ListServerResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    [ListServerRequest.page_size], use `next_page_token` as the value
    for the [ListServerRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def servers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.server_pb2.Server]:
        """List of Server resources."""

    def __init__(
        self,
        *,
        servers: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.server_pb2.Server] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "servers", b"servers"]) -> None: ...

global___ListServerResponse = ListServerResponse

@typing.final
class CreateServerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    HARDWARE_POOL_ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_ID_FIELD_NUMBER: builtins.int
    RENTAL_PERIOD_ID_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACES_FIELD_NUMBER: builtins.int
    OS_SETTINGS_SPEC_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create server in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the server.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the server."""
    hardware_pool_id: builtins.str
    """ID of the hardware pool that the server belongs to.

    To get the hardware pool ID, use a [HardwarePoolService.List] request.
    """
    configuration_id: builtins.str
    """ID of the configuration to use for the server.

    To get the configuration ID, use a [ConfigurationService.List] request.
    """
    rental_period_id: builtins.str
    """A period of time for which the server is rented."""
    @property
    def network_interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkInterfaceSpec]:
        """Network configuration for the server. Specifies how the network interface is configured
        to interact with other servers on the internal network and on the internet.
        Currently up to 2 network interfaces are supported: required private network interface and
        optional public network interface.
        """

    @property
    def os_settings_spec(self) -> global___OsSettingsSpec:
        """Operating system specific settings for provisioning the server. Optional, if omitted, the
        server will be created without an operating system.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        hardware_pool_id: builtins.str = ...,
        configuration_id: builtins.str = ...,
        rental_period_id: builtins.str = ...,
        network_interfaces: collections.abc.Iterable[global___NetworkInterfaceSpec] | None = ...,
        os_settings_spec: global___OsSettingsSpec | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["os_settings_spec", b"os_settings_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["configuration_id", b"configuration_id", "description", b"description", "folder_id", b"folder_id", "hardware_pool_id", b"hardware_pool_id", "labels", b"labels", "name", b"name", "network_interfaces", b"network_interfaces", "os_settings_spec", b"os_settings_spec", "rental_period_id", b"rental_period_id"]) -> None: ...

global___CreateServerRequest = CreateServerRequest

@typing.final
class CreateServerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the server that is being created."""
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___CreateServerMetadata = CreateServerMetadata

@typing.final
class UpdateServerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SERVER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the server to update.

    To get the server ID, use a [ServerService.List] request.
    """
    name: builtins.str
    """Name of the server.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the server."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Server resource are going to be updated."""

    @property
    def network_interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkInterfaceSpec]:
        """Network configuration for the server. Specifies how the network interface is configured
        to interact with other servers on the internal network and on the internet.
        Currently up to 2 network interfaces are supported: required private network interface and
        optional public network interface.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        network_interfaces: collections.abc.Iterable[global___NetworkInterfaceSpec] | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "network_interfaces", b"network_interfaces", "server_id", b"server_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateServerRequest = UpdateServerRequest

@typing.final
class NetworkInterfaceSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PRIVATE_SUBNET_FIELD_NUMBER: builtins.int
    PUBLIC_SUBNET_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the network interface. Should not be specified when creating a server."""
    @property
    def private_subnet(self) -> yandex.cloud.baremetal.v1alpha.server_pb2.PrivateSubnetNetworkInterface:
        """Private subnet."""

    @property
    def public_subnet(self) -> yandex.cloud.baremetal.v1alpha.server_pb2.PublicSubnetNetworkInterface:
        """Public subnet."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        private_subnet: yandex.cloud.baremetal.v1alpha.server_pb2.PrivateSubnetNetworkInterface | None = ...,
        public_subnet: yandex.cloud.baremetal.v1alpha.server_pb2.PublicSubnetNetworkInterface | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["private_subnet", b"private_subnet", "public_subnet", b"public_subnet", "subnet", b"subnet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "private_subnet", b"private_subnet", "public_subnet", b"public_subnet", "subnet", b"subnet"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["subnet", b"subnet"]) -> typing.Literal["private_subnet", "public_subnet"] | None: ...

global___NetworkInterfaceSpec = NetworkInterfaceSpec

@typing.final
class UpdateServerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the Server resource that is being updated."""
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___UpdateServerMetadata = UpdateServerMetadata

@typing.final
class DeleteServerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the server to delete.

    To get the server ID, use a [ServerService.List] request.
    """
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___DeleteServerRequest = DeleteServerRequest

@typing.final
class DeleteServerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the Server resource that is being deleted."""
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___DeleteServerMetadata = DeleteServerMetadata

@typing.final
class PowerOffServerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the server to power off.

    To get the server ID, use a [ServerService.List] request.
    """
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___PowerOffServerRequest = PowerOffServerRequest

@typing.final
class PowerOffServerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the Server resource that is being powered off."""
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___PowerOffServerMetadata = PowerOffServerMetadata

@typing.final
class PowerOnServerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the server to power on.

    To get the server ID, use a [ServerService.List] request.
    """
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___PowerOnServerRequest = PowerOnServerRequest

@typing.final
class PowerOnServerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the Server resource that is being powered on."""
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___PowerOnServerMetadata = PowerOnServerMetadata

@typing.final
class RebootServerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the server to reboot.

    To get the server ID, use a [ServerService.List] request.
    """
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___RebootServerRequest = RebootServerRequest

@typing.final
class RebootServerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the Server resource that is being rebooted."""
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___RebootServerMetadata = RebootServerMetadata

@typing.final
class ReinstallServerRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    OS_SETTINGS_SPEC_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the server to reinstall.

    To get the server ID, use a [ServerService.List] request.
    """
    @property
    def os_settings_spec(self) -> global___OsSettingsSpec:
        """Operating system specific settings for provisioning the server."""

    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
        os_settings_spec: global___OsSettingsSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["os_settings_spec", b"os_settings_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["os_settings_spec", b"os_settings_spec", "server_id", b"server_id"]) -> None: ...

global___ReinstallServerRequest = ReinstallServerRequest

@typing.final
class ReinstallServerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the Server resource that is being reinstalled."""
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___ReinstallServerMetadata = ReinstallServerMetadata

@typing.final
class ListServerOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the Server resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is greater than `page_size`,
    the service returns a [ListServerOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value is 20.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListServerOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "server_id", b"server_id"]) -> None: ...

global___ListServerOperationsRequest = ListServerOperationsRequest

@typing.final
class ListServerOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    [ListServerOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListServerOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified Server resource."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListServerOperationsResponse = ListServerOperationsResponse

@typing.final
class BatchCreateServersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    HARDWARE_POOL_ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_ID_FIELD_NUMBER: builtins.int
    RENTAL_PERIOD_ID_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACES_FIELD_NUMBER: builtins.int
    OS_SETTINGS_SPEC_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list images in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the server.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the server."""
    hardware_pool_id: builtins.str
    """ID of the hardware pool that the server belongs to.

    To get the hardware pool ID, use a [HardwarePoolService.List] request.
    """
    configuration_id: builtins.str
    """ID of the configuration to use for the server.

    To get the configuration ID, use a [ConfigurationService.List] request.
    """
    rental_period_id: builtins.str
    """A period of time for which the server is rented."""
    count: builtins.int
    """Number of servers to create."""
    @property
    def network_interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkInterfaceSpec]:
        """Network configuration for the server. Specifies how the network interface is configured
        to interact with other servers on the internal network and on the internet.
        Currently up to 2 network interfaces are supported: required private network interface and
        optional public network interface.
        """

    @property
    def os_settings_spec(self) -> global___OsSettingsSpec:
        """Operating system specific settings for provisioning the server. Optional, if omitted, the
        server will be created without an operating system.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        hardware_pool_id: builtins.str = ...,
        configuration_id: builtins.str = ...,
        rental_period_id: builtins.str = ...,
        network_interfaces: collections.abc.Iterable[global___NetworkInterfaceSpec] | None = ...,
        os_settings_spec: global___OsSettingsSpec | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["os_settings_spec", b"os_settings_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["configuration_id", b"configuration_id", "count", b"count", "description", b"description", "folder_id", b"folder_id", "hardware_pool_id", b"hardware_pool_id", "labels", b"labels", "name", b"name", "network_interfaces", b"network_interfaces", "os_settings_spec", b"os_settings_spec", "rental_period_id", b"rental_period_id"]) -> None: ...

global___BatchCreateServersRequest = BatchCreateServersRequest

@typing.final
class BatchCreateServersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVERS_FIELD_NUMBER: builtins.int
    @property
    def servers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.server_pb2.Server]:
        """List of Server resources that were created."""

    def __init__(
        self,
        *,
        servers: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.server_pb2.Server] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["servers", b"servers"]) -> None: ...

global___BatchCreateServersResponse = BatchCreateServersResponse

@typing.final
class BatchCreateServersMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_IDS_FIELD_NUMBER: builtins.int
    @property
    def server_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the servers that were created."""

    def __init__(
        self,
        *,
        server_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_ids", b"server_ids"]) -> None: ...

global___BatchCreateServersMetadata = BatchCreateServersMetadata

@typing.final
class QuarantineServerMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the server that is being quarantined."""
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___QuarantineServerMetadata = QuarantineServerMetadata

@typing.final
class StartProlongationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the server that is being prolonged."""
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___StartProlongationRequest = StartProlongationRequest

@typing.final
class StopProlongationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the server to stop prolongation for.

    To get the server ID, use a [ServerService.List] request.
    """
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___StopProlongationRequest = StopProlongationRequest

@typing.final
class ServerSetProlongationMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_ID_FIELD_NUMBER: builtins.int
    server_id: builtins.str
    """ID of the server for which the prolongation is being set."""
    def __init__(
        self,
        *,
        server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["server_id", b"server_id"]) -> None: ...

global___ServerSetProlongationMetadata = ServerSetProlongationMetadata

@typing.final
class OsSettingsSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    STORAGES_FIELD_NUMBER: builtins.int
    SSH_PUBLIC_KEY_FIELD_NUMBER: builtins.int
    USER_SSH_ID_FIELD_NUMBER: builtins.int
    PASSWORD_PLAIN_TEXT_FIELD_NUMBER: builtins.int
    PASSWORD_LOCKBOX_SECRET_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the image that the server was created from."""
    ssh_public_key: builtins.str
    """Public SSH key for the server."""
    user_ssh_id: builtins.str
    """ID of the user SSH key to use for the server.

    To get the user SSH key ID, use a [yandex.cloud.organizationmanager.v1.UserSshKeyService.List] request.
    """
    password_plain_text: builtins.str
    """Raw password."""
    @property
    def storages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.storage_pb2.Storage]:
        """List of storages to be created on the server. If not specified, the default value based on the
        selected configuration will be used as the field value.
        """

    @property
    def password_lockbox_secret(self) -> global___LockboxSecret:
        """Reference to the Lockbox secret used to obtain the password."""

    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
        storages: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.storage_pb2.Storage] | None = ...,
        ssh_public_key: builtins.str = ...,
        user_ssh_id: builtins.str = ...,
        password_plain_text: builtins.str = ...,
        password_lockbox_secret: global___LockboxSecret | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["password", b"password", "password_lockbox_secret", b"password_lockbox_secret", "password_plain_text", b"password_plain_text", "ssh_key", b"ssh_key", "ssh_public_key", b"ssh_public_key", "user_ssh_id", b"user_ssh_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id", "password", b"password", "password_lockbox_secret", b"password_lockbox_secret", "password_plain_text", b"password_plain_text", "ssh_key", b"ssh_key", "ssh_public_key", b"ssh_public_key", "storages", b"storages", "user_ssh_id", b"user_ssh_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["password", b"password"]) -> typing.Literal["password_plain_text", "password_lockbox_secret"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["ssh_key", b"ssh_key"]) -> typing.Literal["ssh_public_key", "user_ssh_id"] | None: ...

global___OsSettingsSpec = OsSettingsSpec

@typing.final
class LockboxSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    secret_id: builtins.str
    """The unique identifier for the lockbox secret that contains the user password."""
    version_id: builtins.str
    """The unique identifier for the lockbox version.
    If omitted, the current version of the secret will be used.
    """
    key: builtins.str
    """The key used to access a specific secret entry."""
    def __init__(
        self,
        *,
        secret_id: builtins.str = ...,
        version_id: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "secret_id", b"secret_id", "version_id", b"version_id"]) -> None: ...

global___LockboxSecret = LockboxSecret



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cic/v1/trunk_connection.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cic/v1/trunk_connection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.cic.v1.common import transceiver_type_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_common_dot_transceiver__type__pb2
from yandex.cloud.cic.v1.common import lag_allocation_settings_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_common_dot_lag__allocation__settings__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/cic/v1/trunk_connection.proto\x12\x13yandex.cloud.cic.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31yandex/cloud/cic/v1/common/transceiver_type.proto\x1a\x38yandex/cloud/cic/v1/common/lag_allocation_settings.proto\"\xf1\r\n\x0fTrunkConnection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x05 \x01(\t\x12\x11\n\tregion_id\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12^\n\x18single_port_direct_joint\x18\t \x01(\x0b\x32:.yandex.cloud.cic.v1.TrunkConnection.SinglePortDirectJointH\x00\x12O\n\x10lag_direct_joint\x18\n \x01(\x0b\x32\x33.yandex.cloud.cic.v1.TrunkConnection.LagDirectJointH\x00\x12S\n\x12partner_joint_info\x18\x0b \x01(\x0b\x32\x35.yandex.cloud.cic.v1.TrunkConnection.PartnerJointInfoH\x00\x12:\n\x14point_of_presence_id\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x08\x63\x61pacity\x18\x16 \x01(\x0e\x32-.yandex.cloud.cic.v1.TrunkConnection.Capacity\x12@\n\x06labels\x18\x17 \x03(\x0b\x32\x30.yandex.cloud.cic.v1.TrunkConnection.LabelsEntry\x12;\n\x06status\x18\x18 \x01(\x0e\x32+.yandex.cloud.cic.v1.TrunkConnection.Status\x12\x1b\n\x13\x64\x65letion_protection\x18\x19 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a_\n\x10PartnerJointInfo\x12\x13\n\x0bservice_key\x18\x03 \x01(\t\x12\x30\n\npartner_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueJ\x04\x08\x01\x10\x03\x1a\xb1\x01\n\x15SinglePortDirectJoint\x12\x45\n\x10transceiver_type\x18\x01 \x01(\x0e\x32+.yandex.cloud.cic.v1.common.TransceiverType\x12/\n\tport_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1a\n\x12\x61\x63\x63\x65ss_device_name\x18\x04 \x01(\tJ\x04\x08\x02\x10\x03\x1a\xcd\x01\n\x0eLagDirectJoint\x12\x45\n\x10transceiver_type\x18\x01 \x01(\x0e\x32+.yandex.cloud.cic.v1.common.TransceiverType\x12R\n\x17lag_allocation_settings\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.cic.v1.common.LagAllocationSettings\x12\x1a\n\x12\x61\x63\x63\x65ss_device_name\x18\x04 \x01(\tJ\x04\x08\x02\x10\x03\"\xb2\x03\n\x08\x43\x61pacity\x12\x18\n\x14\x43\x41PACITY_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43\x41PACITY_50_MBPS\x10\x01\x12\x15\n\x11\x43\x41PACITY_100_MBPS\x10\x02\x12\x15\n\x11\x43\x41PACITY_200_MBPS\x10\x03\x12\x15\n\x11\x43\x41PACITY_300_MBPS\x10\x04\x12\x15\n\x11\x43\x41PACITY_400_MBPS\x10\x05\x12\x15\n\x11\x43\x41PACITY_500_MBPS\x10\x06\x12\x13\n\x0f\x43\x41PACITY_1_GBPS\x10\x07\x12\x13\n\x0f\x43\x41PACITY_2_GBPS\x10\x08\x12\x13\n\x0f\x43\x41PACITY_3_GBPS\x10\t\x12\x13\n\x0f\x43\x41PACITY_4_GBPS\x10\n\x12\x13\n\x0f\x43\x41PACITY_5_GBPS\x10\x0b\x12\x14\n\x10\x43\x41PACITY_10_GBPS\x10\x0c\x12\x14\n\x10\x43\x41PACITY_20_GBPS\x10\r\x12\x14\n\x10\x43\x41PACITY_30_GBPS\x10\x0e\x12\x14\n\x10\x43\x41PACITY_40_GBPS\x10\x0f\x12\x14\n\x10\x43\x41PACITY_50_GBPS\x10\x10\x12\x15\n\x11\x43\x41PACITY_100_GBPS\x10\x11\x12\x15\n\x11\x43\x41PACITY_200_GBPS\x10\x12\"V\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0c\n\x08UPDATING\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x41\x43TIVE\x10\x04\x42\x07\n\x05jointJ\x04\x08\x04\x10\x05J\x04\x08\x08\x10\tJ\x04\x08\r\x10\x16\x42V\n\x17yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.trunk_connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cic'
  _globals['_TRUNKCONNECTION_LABELSENTRY']._loaded_options = None
  _globals['_TRUNKCONNECTION_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_TRUNKCONNECTION']._serialized_start=242
  _globals['_TRUNKCONNECTION']._serialized_end=2019
  _globals['_TRUNKCONNECTION_LABELSENTRY']._serialized_start=937
  _globals['_TRUNKCONNECTION_LABELSENTRY']._serialized_end=982
  _globals['_TRUNKCONNECTION_PARTNERJOINTINFO']._serialized_start=984
  _globals['_TRUNKCONNECTION_PARTNERJOINTINFO']._serialized_end=1079
  _globals['_TRUNKCONNECTION_SINGLEPORTDIRECTJOINT']._serialized_start=1082
  _globals['_TRUNKCONNECTION_SINGLEPORTDIRECTJOINT']._serialized_end=1259
  _globals['_TRUNKCONNECTION_LAGDIRECTJOINT']._serialized_start=1262
  _globals['_TRUNKCONNECTION_LAGDIRECTJOINT']._serialized_end=1467
  _globals['_TRUNKCONNECTION_CAPACITY']._serialized_start=1470
  _globals['_TRUNKCONNECTION_CAPACITY']._serialized_end=1904
  _globals['_TRUNKCONNECTION_STATUS']._serialized_start=1906
  _globals['_TRUNKCONNECTION_STATUS']._serialized_end=1992
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/clouddesktop/v1/desktop_group_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/clouddesktop/v1/desktop_group_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.clouddesktop.v1 import desktop_pb2 as yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__pb2
from yandex.cloud.clouddesktop.v1 import desktop_group_pb2 as yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.clouddesktop.v1 import disk_pb2 as yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_disk__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/clouddesktop/v1/desktop_group_service.proto\x12 yandex.cloud.clouddesktop.v1.api\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a*yandex/cloud/clouddesktop/v1/desktop.proto\x1a\x30yandex/cloud/clouddesktop/v1/desktop_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\x1a\'yandex/cloud/clouddesktop/v1/disk.proto\"@\n\x16GetDesktopGroupRequest\x12&\n\x10\x64\x65sktop_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xb8\x01\n\x18ListDesktopGroupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x15 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x16 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x17 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x18 \x01(\tB\t\x8a\xc8\x31\x05<=100J\x04\x08\x02\x10\x15\"\x82\x01\n\x19ListDesktopGroupsResponse\x12\x46\n\x0e\x64\x65sktop_groups\x18\x01 \x03(\x0b\x32..yandex.cloud.clouddesktop.v1.api.DesktopGroup\x12\x17\n\x0fnext_page_token\x18\x16 \x01(\tJ\x04\x08\x02\x10\x16\"\xc6\x01\n\x1fListDesktopGroupDesktopsRequest\x12&\n\x10\x64\x65sktop_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x15 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x16 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x17 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x18 \x01(\tB\t\x8a\xc8\x31\x05<=100J\x04\x08\x02\x10\x15\"~\n ListDesktopGroupDesktopsResponse\x12;\n\x08\x64\x65sktops\x18\x01 \x03(\x0b\x32).yandex.cloud.clouddesktop.v1.api.Desktop\x12\x17\n\x0fnext_page_token\x18\x16 \x01(\tJ\x04\x08\x02\x10\x16\"\xab\x01\n!ListDesktopGroupOperationsRequest\x12&\n\x10\x64\x65sktop_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x15 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x16 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x17 \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x15\"z\n\"ListDesktopGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x16 \x01(\tJ\x04\x08\x02\x10\x16\"\x95\x07\n\x19UpdateDesktopGroupRequest\x12&\n\x10\x64\x65sktop_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\"\n\x10\x64\x65sktop_image_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x31\n\x04name\x18\x04 \x01(\tB#\xf2\xc7\x31\x1f|[a-z]([-a-z0-9]{0,61}[a-z0-9])\x12\x1f\n\x0b\x64\x65scription\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x94\x01\n\x06labels\x18\x06 \x03(\x0b\x32G.yandex.cloud.clouddesktop.v1.api.UpdateDesktopGroupRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12G\n\x0eresources_spec\x18\x07 \x01(\x0b\x32/.yandex.cloud.clouddesktop.v1.api.ResourcesSpec\x12Q\n\x0cgroup_config\x18\n \x01(\x0b\x32;.yandex.cloud.clouddesktop.v1.api.DesktopGroupConfiguration\x12\x42\n\x0e\x62oot_disk_spec\x18\x0b \x01(\x0b\x32*.yandex.cloud.clouddesktop.v1.api.DiskSpec\x12\x42\n\x0e\x64\x61ta_disk_spec\x18\x0c \x01(\x0b\x32*.yandex.cloud.clouddesktop.v1.api.DiskSpec\x12P\n\x12\x61uto_update_policy\x18\r \x01(\x0b\x32\x32.yandex.cloud.clouddesktop.v1.api.AutoUpdatePolicyH\x00\x12T\n\x14manual_update_policy\x18\x0e \x01(\x0b\x32\x34.yandex.cloud.clouddesktop.v1.api.ManualUpdatePolicyH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\rupdate_policyJ\x04\x08\x08\x10\n\"\xbf\x04\n\x19\x43reateDesktopGroupRequest\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12&\n\x10\x64\x65sktop_image_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\x04name\x18\x0b \x01(\tB\"\xf2\xc7\x31\x1e[a-z]([-a-z0-9]{0,61}[a-z0-9])\x12\x1f\n\x0b\x64\x65scription\x18\x0c \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12G\n\x0eresources_spec\x18\x15 \x01(\x0b\x32/.yandex.cloud.clouddesktop.v1.api.ResourcesSpec\x12V\n\x16network_interface_spec\x18\x16 \x01(\x0b\x32\x36.yandex.cloud.clouddesktop.v1.api.NetworkInterfaceSpec\x12\x42\n\x0e\x62oot_disk_spec\x18\x17 \x01(\x0b\x32*.yandex.cloud.clouddesktop.v1.api.DiskSpec\x12\x42\n\x0e\x64\x61ta_disk_spec\x18\x18 \x01(\x0b\x32*.yandex.cloud.clouddesktop.v1.api.DiskSpec\x12Q\n\x0cgroup_config\x18\x19 \x01(\x0b\x32;.yandex.cloud.clouddesktop.v1.api.DesktopGroupConfigurationJ\x04\x08\r\x10\x15J\x04\x08\x04\x10\x0b\"6\n\x1a\x43reateDesktopGroupMetadata\x12\x18\n\x10\x64\x65sktop_group_id\x18\x01 \x01(\t\"C\n\x19\x44\x65leteDesktopGroupRequest\x12&\n\x10\x64\x65sktop_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n\x1a\x44\x65leteDesktopGroupMetadata\x12\x18\n\x10\x64\x65sktop_group_id\x18\x01 \x01(\t\"6\n\x1aUpdateDesktopGroupMetadata\x12\x18\n\x10\x64\x65sktop_group_id\x18\x01 \x01(\t2\xe6\x10\n\x13\x44\x65sktopGroupService\x12\xab\x01\n\x03Get\x12\x38.yandex.cloud.clouddesktop.v1.api.GetDesktopGroupRequest\x1a..yandex.cloud.clouddesktop.v1.api.DesktopGroup\":\x82\xd3\xe4\x93\x02\x34\x12\x32/cloud-desktop/v1/desktopGroups/{desktop_group_id}\x12\xa8\x01\n\x04List\x12:.yandex.cloud.clouddesktop.v1.api.ListDesktopGroupsRequest\x1a;.yandex.cloud.clouddesktop.v1.api.ListDesktopGroupsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/cloud-desktop/v1/desktopGroups\x12\xda\x01\n\x0cListDesktops\x12\x41.yandex.cloud.clouddesktop.v1.api.ListDesktopGroupDesktopsRequest\x1a\x42.yandex.cloud.clouddesktop.v1.api.ListDesktopGroupDesktopsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/cloud-desktop/v1/desktopGroups/{desktop_group_id}/desktops\x12\xe2\x01\n\x0eListOperations\x12\x43.yandex.cloud.clouddesktop.v1.api.ListDesktopGroupOperationsRequest\x1a\x44.yandex.cloud.clouddesktop.v1.api.ListDesktopGroupOperationsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/cloud-desktop/v1/desktopGroups/{desktop_group_id}/operations\x12\xc2\x01\n\x06\x43reate\x12;.yandex.cloud.clouddesktop.v1.api.CreateDesktopGroupRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2**\n\x1a\x43reateDesktopGroupMetadata\x12\x0c\x44\x65sktopGroup\x82\xd3\xe4\x93\x02$\"\x1f/cloud-desktop/v1/desktopGroups:\x01*\x12\xde\x01\n\x06Update\x12;.yandex.cloud.clouddesktop.v1.api.UpdateDesktopGroupRequest\x1a!.yandex.cloud.operation.Operation\"t\xb2\xd2*3\n\x1aUpdateDesktopGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x37\x32\x32/cloud-desktop/v1/desktopGroups/{desktop_group_id}:\x01*\x12\xdb\x01\n\x06\x44\x65lete\x12;.yandex.cloud.clouddesktop.v1.api.DeleteDesktopGroupRequest\x1a!.yandex.cloud.operation.Operation\"q\xb2\xd2*3\n\x1a\x44\x65leteDesktopGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x34*2/cloud-desktop/v1/desktopGroups/{desktop_group_id}\x12\xbf\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/cloud-desktop/v1/desktopGroups/{resource_id}:listAccessBindings\x12\xef\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x87\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x44\"?/cloud-desktop/v1/desktopGroups/{resource_id}:setAccessBindings:\x01*\x12\xfb\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8d\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02G\"B/cloud-desktop/v1/desktopGroups/{resource_id}:updateAccessBindings:\x01*Bq\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktopb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.clouddesktop.v1.desktop_group_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktop'
  _globals['_GETDESKTOPGROUPREQUEST'].fields_by_name['desktop_group_id']._loaded_options = None
  _globals['_GETDESKTOPGROUPREQUEST'].fields_by_name['desktop_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDESKTOPGROUPSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTDESKTOPGROUPSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDESKTOPGROUPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDESKTOPGROUPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDESKTOPGROUPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDESKTOPGROUPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDESKTOPGROUPSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDESKTOPGROUPSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDESKTOPGROUPSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDESKTOPGROUPSREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDESKTOPGROUPDESKTOPSREQUEST'].fields_by_name['desktop_group_id']._loaded_options = None
  _globals['_LISTDESKTOPGROUPDESKTOPSREQUEST'].fields_by_name['desktop_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDESKTOPGROUPDESKTOPSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDESKTOPGROUPDESKTOPSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDESKTOPGROUPDESKTOPSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDESKTOPGROUPDESKTOPSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDESKTOPGROUPDESKTOPSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDESKTOPGROUPDESKTOPSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDESKTOPGROUPDESKTOPSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDESKTOPGROUPDESKTOPSREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDESKTOPGROUPOPERATIONSREQUEST'].fields_by_name['desktop_group_id']._loaded_options = None
  _globals['_LISTDESKTOPGROUPOPERATIONSREQUEST'].fields_by_name['desktop_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDESKTOPGROUPOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDESKTOPGROUPOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDESKTOPGROUPOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDESKTOPGROUPOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDESKTOPGROUPOPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDESKTOPGROUPOPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_UPDATEDESKTOPGROUPREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEDESKTOPGROUPREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDESKTOPGROUPREQUEST'].fields_by_name['desktop_group_id']._loaded_options = None
  _globals['_UPDATEDESKTOPGROUPREQUEST'].fields_by_name['desktop_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEDESKTOPGROUPREQUEST'].fields_by_name['desktop_image_id']._loaded_options = None
  _globals['_UPDATEDESKTOPGROUPREQUEST'].fields_by_name['desktop_image_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATEDESKTOPGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEDESKTOPGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\037|[a-z]([-a-z0-9]{0,61}[a-z0-9])'
  _globals['_UPDATEDESKTOPGROUPREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEDESKTOPGROUPREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATEDESKTOPGROUPREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEDESKTOPGROUPREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATEDESKTOPGROUPREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEDESKTOPGROUPREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEDESKTOPGROUPREQUEST'].fields_by_name['desktop_image_id']._loaded_options = None
  _globals['_CREATEDESKTOPGROUPREQUEST'].fields_by_name['desktop_image_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEDESKTOPGROUPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEDESKTOPGROUPREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\036[a-z]([-a-z0-9]{0,61}[a-z0-9])'
  _globals['_CREATEDESKTOPGROUPREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEDESKTOPGROUPREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_DELETEDESKTOPGROUPREQUEST'].fields_by_name['desktop_group_id']._loaded_options = None
  _globals['_DELETEDESKTOPGROUPREQUEST'].fields_by_name['desktop_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0024\0222/cloud-desktop/v1/desktopGroups/{desktop_group_id}'
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/cloud-desktop/v1/desktopGroups'
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['ListDesktops']._loaded_options = None
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['ListDesktops']._serialized_options = b'\202\323\344\223\002=\022;/cloud-desktop/v1/desktopGroups/{desktop_group_id}/desktops'
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002?\022=/cloud-desktop/v1/desktopGroups/{desktop_group_id}/operations'
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322**\n\032CreateDesktopGroupMetadata\022\014DesktopGroup\202\323\344\223\002$\"\037/cloud-desktop/v1/desktopGroups:\001*'
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*3\n\032UpdateDesktopGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002722/cloud-desktop/v1/desktopGroups/{desktop_group_id}:\001*'
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*3\n\032DeleteDesktopGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\0024*2/cloud-desktop/v1/desktopGroups/{desktop_group_id}'
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002B\022@/cloud-desktop/v1/desktopGroups/{resource_id}:listAccessBindings'
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002D\"?/cloud-desktop/v1/desktopGroups/{resource_id}:setAccessBindings:\001*'
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_DESKTOPGROUPSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002G\"B/cloud-desktop/v1/desktopGroups/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETDESKTOPGROUPREQUEST']._serialized_start=432
  _globals['_GETDESKTOPGROUPREQUEST']._serialized_end=496
  _globals['_LISTDESKTOPGROUPSREQUEST']._serialized_start=499
  _globals['_LISTDESKTOPGROUPSREQUEST']._serialized_end=683
  _globals['_LISTDESKTOPGROUPSRESPONSE']._serialized_start=686
  _globals['_LISTDESKTOPGROUPSRESPONSE']._serialized_end=816
  _globals['_LISTDESKTOPGROUPDESKTOPSREQUEST']._serialized_start=819
  _globals['_LISTDESKTOPGROUPDESKTOPSREQUEST']._serialized_end=1017
  _globals['_LISTDESKTOPGROUPDESKTOPSRESPONSE']._serialized_start=1019
  _globals['_LISTDESKTOPGROUPDESKTOPSRESPONSE']._serialized_end=1145
  _globals['_LISTDESKTOPGROUPOPERATIONSREQUEST']._serialized_start=1148
  _globals['_LISTDESKTOPGROUPOPERATIONSREQUEST']._serialized_end=1319
  _globals['_LISTDESKTOPGROUPOPERATIONSRESPONSE']._serialized_start=1321
  _globals['_LISTDESKTOPGROUPOPERATIONSRESPONSE']._serialized_end=1443
  _globals['_UPDATEDESKTOPGROUPREQUEST']._serialized_start=1446
  _globals['_UPDATEDESKTOPGROUPREQUEST']._serialized_end=2363
  _globals['_UPDATEDESKTOPGROUPREQUEST_LABELSENTRY']._serialized_start=2295
  _globals['_UPDATEDESKTOPGROUPREQUEST_LABELSENTRY']._serialized_end=2340
  _globals['_CREATEDESKTOPGROUPREQUEST']._serialized_start=2366
  _globals['_CREATEDESKTOPGROUPREQUEST']._serialized_end=2941
  _globals['_CREATEDESKTOPGROUPMETADATA']._serialized_start=2943
  _globals['_CREATEDESKTOPGROUPMETADATA']._serialized_end=2997
  _globals['_DELETEDESKTOPGROUPREQUEST']._serialized_start=2999
  _globals['_DELETEDESKTOPGROUPREQUEST']._serialized_end=3066
  _globals['_DELETEDESKTOPGROUPMETADATA']._serialized_start=3068
  _globals['_DELETEDESKTOPGROUPMETADATA']._serialized_end=3122
  _globals['_UPDATEDESKTOPGROUPMETADATA']._serialized_start=3124
  _globals['_UPDATEDESKTOPGROUPMETADATA']._serialized_end=3178
  _globals['_DESKTOPGROUPSERVICE']._serialized_start=3181
  _globals['_DESKTOPGROUPSERVICE']._serialized_end=5331
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.kms.v1.symmetric_key_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateSymmetricKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DEFAULT_ALGORITHM_FIELD_NUMBER: builtins.int
    ROTATION_PERIOD_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a symmetric KMS key in."""
    name: builtins.str
    """Name of the key."""
    description: builtins.str
    """Description of the key."""
    default_algorithm: yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricAlgorithm.ValueType
    """Encryption algorithm to be used with a new key version, generated with the next rotation."""
    deletion_protection: builtins.bool
    """Flag that inhibits deletion of the symmetric KMS key"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the symmetric KMS key as `key:value` pairs. Maximum 64 per key.
        For example, `"project": "mvp"` or `"source": "dictionary"`.
        """

    @property
    def rotation_period(self) -> google.protobuf.duration_pb2.Duration:
        """Interval between automatic rotations. To disable automatic rotation, don't include
        this field in the creation request.
        """

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        default_algorithm: yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricAlgorithm.ValueType = ...,
        rotation_period: google.protobuf.duration_pb2.Duration | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["rotation_period", b"rotation_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_algorithm", b"default_algorithm", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "rotation_period", b"rotation_period"]) -> None: ...

global___CreateSymmetricKeyRequest = CreateSymmetricKeyRequest

@typing.final
class CreateSymmetricKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    PRIMARY_VERSION_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key being created."""
    primary_version_id: builtins.str
    """ID of the primary version of the key being created."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        primary_version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "primary_version_id", b"primary_version_id"]) -> None: ...

global___CreateSymmetricKeyMetadata = CreateSymmetricKeyMetadata

@typing.final
class GetSymmetricKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the symmetric KMS key to return.
    To get the ID of a symmetric KMS key use a [SymmetricKeyService.List] request.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___GetSymmetricKeyRequest = GetSymmetricKeyRequest

@typing.final
class ListSymmetricKeysRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list symmetric KMS keys in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListSymmetricKeysResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListSymmetricKeysResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListSymmetricKeysRequest = ListSymmetricKeysRequest

@typing.final
class ListSymmetricKeysResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number
    of results is greater than the specified [ListSymmetricKeysRequest.page_size], use
    the [next_page_token] as the value for the [ListSymmetricKeysRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricKey]:
        """List of symmetric KMS keys in the specified folder."""

    def __init__(
        self,
        *,
        keys: collections.abc.Iterable[yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricKey] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["keys", b"keys", "next_page_token", b"next_page_token"]) -> None: ...

global___ListSymmetricKeysResponse = ListSymmetricKeysResponse

@typing.final
class ListSymmetricKeyVersionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the symmetric KMS key to list versions for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListSymmetricKeyVersionsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListSymmetricKeyVersionsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListSymmetricKeyVersionsRequest = ListSymmetricKeyVersionsRequest

@typing.final
class ListSymmetricKeyVersionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_VERSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number
    of results is greater than the specified [ListSymmetricKeyVersionsRequest.page_size], use
    the [next_page_token] as the value for the [ListSymmetricKeyVersionsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def key_versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricKeyVersion]:
        """List of versions for the specified symmetric KMS key."""

    def __init__(
        self,
        *,
        key_versions: collections.abc.Iterable[yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricKeyVersion] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_versions", b"key_versions", "next_page_token", b"next_page_token"]) -> None: ...

global___ListSymmetricKeyVersionsResponse = ListSymmetricKeyVersionsResponse

@typing.final
class UpdateSymmetricKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    KEY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DEFAULT_ALGORITHM_FIELD_NUMBER: builtins.int
    ROTATION_PERIOD_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the symmetric KMS key to update.
    To get the ID of a symmetric KMS key use a [SymmetricKeyService.List] request.
    """
    name: builtins.str
    """New name for the symmetric KMS key."""
    description: builtins.str
    """New description for the symmetric KMS key."""
    status: yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricKey.Status.ValueType
    """New status for the symmetric KMS key.
    Using the [SymmetricKeyService.Update] method you can only set ACTIVE or INACTIVE status.
    """
    default_algorithm: yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricAlgorithm.ValueType
    """Default encryption algorithm to be used with new versions of the symmetric KMS key."""
    deletion_protection: builtins.bool
    """Flag that inhibits deletion of the symmetric KMS key"""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the symmetric KMS key are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the symmetric KMS key as `key:value` pairs. Maximum 64 per key."""

    @property
    def rotation_period(self) -> google.protobuf.duration_pb2.Duration:
        """Time period between automatic symmetric KMS key rotations.
        period between two automatic rotations
        """

    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        status: yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricKey.Status.ValueType = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        default_algorithm: yandex.cloud.kms.v1.symmetric_key_pb2.SymmetricAlgorithm.ValueType = ...,
        rotation_period: google.protobuf.duration_pb2.Duration | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["rotation_period", b"rotation_period", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_algorithm", b"default_algorithm", "deletion_protection", b"deletion_protection", "description", b"description", "key_id", b"key_id", "labels", b"labels", "name", b"name", "rotation_period", b"rotation_period", "status", b"status", "update_mask", b"update_mask"]) -> None: ...

global___UpdateSymmetricKeyRequest = UpdateSymmetricKeyRequest

@typing.final
class UpdateSymmetricKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key being updated."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___UpdateSymmetricKeyMetadata = UpdateSymmetricKeyMetadata

@typing.final
class DeleteSymmetricKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key to be deleted."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___DeleteSymmetricKeyRequest = DeleteSymmetricKeyRequest

@typing.final
class DeleteSymmetricKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key being deleted."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___DeleteSymmetricKeyMetadata = DeleteSymmetricKeyMetadata

@typing.final
class SetPrimarySymmetricKeyVersionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key to set a primary version for."""
    version_id: builtins.str
    """ID of the version that should become primary for the specified key."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "version_id", b"version_id"]) -> None: ...

global___SetPrimarySymmetricKeyVersionRequest = SetPrimarySymmetricKeyVersionRequest

@typing.final
class SetPrimarySymmetricKeyVersionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key that the primary version if being changed for."""
    version_id: builtins.str
    """ID of the version that is being made primary for the key."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "version_id", b"version_id"]) -> None: ...

global___SetPrimarySymmetricKeyVersionMetadata = SetPrimarySymmetricKeyVersionMetadata

@typing.final
class RotateSymmetricKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key to be rotated."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___RotateSymmetricKeyRequest = RotateSymmetricKeyRequest

@typing.final
class RotateSymmetricKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    NEW_PRIMARY_VERSION_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key being rotated."""
    new_primary_version_id: builtins.str
    """ID of the version generated as a result of key rotation."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        new_primary_version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "new_primary_version_id", b"new_primary_version_id"]) -> None: ...

global___RotateSymmetricKeyMetadata = RotateSymmetricKeyMetadata

@typing.final
class ScheduleSymmetricKeyVersionDestructionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    PENDING_PERIOD_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key whose version should be scheduled for destruction."""
    version_id: builtins.str
    """ID of the version to be destroyed."""
    @property
    def pending_period(self) -> google.protobuf.duration_pb2.Duration:
        """Time interval between the version destruction request and actual destruction.
        Default value: 7 days.
        """

    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
        pending_period: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pending_period", b"pending_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "pending_period", b"pending_period", "version_id", b"version_id"]) -> None: ...

global___ScheduleSymmetricKeyVersionDestructionRequest = ScheduleSymmetricKeyVersionDestructionRequest

@typing.final
class ScheduleSymmetricKeyVersionDestructionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    DESTROY_AT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key whose version is being scheduled for destruction."""
    version_id: builtins.str
    """ID of the version that is being scheduled for destruction."""
    @property
    def destroy_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the version is scheduled to be destroyed."""

    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
        destroy_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destroy_at", b"destroy_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destroy_at", b"destroy_at", "key_id", b"key_id", "version_id", b"version_id"]) -> None: ...

global___ScheduleSymmetricKeyVersionDestructionMetadata = ScheduleSymmetricKeyVersionDestructionMetadata

@typing.final
class CancelSymmetricKeyVersionDestructionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key to cancel a version's destruction for."""
    version_id: builtins.str
    """ID of the version whose scheduled destruction should be cancelled."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "version_id", b"version_id"]) -> None: ...

global___CancelSymmetricKeyVersionDestructionRequest = CancelSymmetricKeyVersionDestructionRequest

@typing.final
class CancelSymmetricKeyVersionDestructionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the key whose version's destruction is being cancelled."""
    version_id: builtins.str
    """ID of the version whose scheduled destruction is being cancelled."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "version_id", b"version_id"]) -> None: ...

global___CancelSymmetricKeyVersionDestructionMetadata = CancelSymmetricKeyVersionDestructionMetadata

@typing.final
class ListSymmetricKeyOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the symmetric KMS key to get operations for.

    To get the key ID, use a [SymmetricKeyService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size], the service returns a [ListSymmetricKeyOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListSymmetricKeyOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListSymmetricKeyOperationsRequest = ListSymmetricKeyOperationsRequest

@typing.final
class ListSymmetricKeyOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListSymmetricKeyOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListSymmetricKeyOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified key."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListSymmetricKeyOperationsResponse = ListSymmetricKeyOperationsResponse
